import {
  ParameterUtil,
  APIEncoder,
  APIDecoder,
  HttpUrlEncodingCodec
} from '@ucap-webmessenger/api';

import { PIRequest, PIResponse } from './pi';
import { HttpParams, HttpParameterCodec } from '@angular/common/http';

export interface Login2Request extends PIRequest {
  companyCode: string;
  loginId: string;
  loginPw: string;
}

export interface Login2Response extends PIResponse {
  status: string;
  version: string;
  passwordHc: string;
  personalInfoAgreeYn: string;
  companyCode: string;
  userId: string;
  userName: string;
  userSeq: number;
}

const login2EncodeMap = {
  companyCode: 'companyCd',
  loginId: 'loginId',
  loginPw: 'loginPw'
};

export const encodeLogin2: APIEncoder<Login2Request> = (req: Login2Request) => {
  let parameter: HttpParams = new HttpParams({
    encoder: new HttpUrlEncodingCodec()
  });
  parameter = parameter.append('companyCd', req.companyCode);
  parameter = parameter.append('loginId', req.loginId);
  parameter = parameter.append('loginPw', req.loginPw);
  return parameter;
  // return ParameterUtil.encodeForm(login2EncodeMap, req);
};

export const decodeLogin2: APIDecoder<Login2Response> = (res: any) => {
  return {
    status: res.STATUS,
    version: res.VER,
    passwordHc: res.PWD_HC,
    personalInfoAgreeYn: res.PER_INFO_AGREE_YN,
    companyCode: res.COMPANY_CODE,
    userId: res.USER_ID,
    userName: res.USER_NAME,
    userSeq: res.USER_SEQ
  } as Login2Response;
};
